"""
    This package owns personnal and useful machine learning
    functions.

    Use :

    >>> from mj_package import proclamer
    >>> proclamer()
"""
# VERSION
__version__ = "0.0.1"

from mj_package.core import proclamer,add,sub

